summary refs log tree commit diff stats
path: root/tools/vccexe
diff options
context:
space:
mode:
authorFederico Ceratto <federico.ceratto@gmail.com>2019-09-27 06:02:54 +0100
committerAndreas Rumpf <rumpf_a@web.de>2019-09-27 07:02:54 +0200
commit39290cf88c5047e86dc4894e3190c63d5985f56f (patch)
treef37c9e0a5491fb9b11266ce08bddc297b57f37fc /tools/vccexe
parent9dd297f613768bb170e05dcaf361015d9448c582 (diff)
downloadNim-39290cf88c5047e86dc4894e3190c63d5985f56f.tar.gz
Fix spellings (#12277) [backport]
Diffstat (limited to 'tools/vccexe')
-rw-r--r--tools/vccexe/vccenv.nim2
-rw-r--r--tools/vccexe/vccexe.nim12
-rw-r--r--tools/vccexe/vcvarsall.nim2
3 files changed, 8 insertions, 8 deletions
diff --git a/tools/vccexe/vccenv.nim b/tools/vccexe/vccenv.nim
index 12a6e6b3d..216760e54 100644
--- a/tools/vccexe/vccenv.nim
+++ b/tools/vccexe/vccenv.nim
@@ -8,7 +8,7 @@ type
                         ## Valid versions are Versions of Visual Studio that permanently set a COMNTOOLS
                         ## environment variable. That includes Visual Studio version up to and including
                         ## Visual Studio 2015
-    vsUndefined = (0, ""), ## Version not specified, use latest recogized version on the system
+    vsUndefined = (0, ""), ## Version not specified, use latest recognized version on the system
     vs90  = (90,   "VS90COMNTOOLS"), ## Visual Studio 2008
     vs100 = (100, "VS100COMNTOOLS"), ## Visual Studio 2010
     vs110 = (110, "VS110COMNTOOLS"), ## Visual Studio 2012
diff --git a/tools/vccexe/vcvarsall.nim b/tools/vccexe/vcvarsall.nim
index 945fb90a6..29d13cc7e 100644
--- a/tools/vccexe/vcvarsall.nim
+++ b/tools/vccexe/vcvarsall.nim
@@ -88,7 +88,7 @@ proc vccVarsAll*(path: string, arch: VccArch = vccarchUnspecified, platform_type
   result = newStringTable(modeCaseInsensitive)
 
   # Parse the output of the final SET command to construct a String Table
-  # with the appropiate environment variables
+  # with the appropriate environment variables
   for line in comSpecOut.splitLines:
     let idx = line.find('=')
     if idx > 0:
diff --git a/tools/vccexe/vccexe.nim b/tools/vccexe/vccexe.nim
index feea6c0c0..e78f9da5e 100644
--- a/tools/vccexe/vccexe.nim
+++ b/tools/vccexe/vccexe.nim
@@ -30,7 +30,7 @@ proc discoverVccVcVarsAllPath*(version: VccVersion = vccUndefined): string =
   if result.len > 0:
     return
 
-  # All attempts to dicover vcc failed
+  # All attempts to discover vcc failed
 
 const 
   vccversionPrefix = "--vccversion"
@@ -73,11 +73,11 @@ Options:
                       of the VCC version specified with the --vccversion argument.
                       For each specified version the utility prints a line with the
                       following format: <version>: <path>
-  --noCommand         Flag to supress VCC secondary command execution
-                      Useful in conjuction with --vccversion and --printPath to
-                      only perfom VCC discovery, but without executing VCC tools
+  --noCommand         Flag to suppress VCC secondary command execution
+                      Useful in conjunction with --vccversion and --printPath to
+                      only perform VCC discovery, but without executing VCC tools
   --vcvarsall:<path>  Path to the Developer Command Prompt utility vcvarsall.bat that selects
-                      the appropiate devlopment settings.
+                      the appropriate development settings.
                       Usual path for Visual Studio 2015 and below:
                         %VSInstallDir%\VC\vcvarsall
                       Usual path for Visual Studio 2017 and above:
@@ -174,7 +174,7 @@ when isMainModule:
       head = "latest"
     echo "$1: $2" % [head, vcvarsallArg]
 
   # Call vcvarsall to get the appropiate VCC process environment
   var vcvars = vccVarsAll(vcvarsallArg, platformArg, sdkTypeArg, sdkVersionArg, verboseArg)
   if vcvars != nil:
     for vccEnvKey, vccEnvVal in vcvars:
@@ -174,7 +174,7 @@ when isMainModule:
     echo "$1: $2" % [head, vcvarsallArg]
 
-  # Call vcvarsall to get the appropiate VCC process environment
+  # Call vcvarsall to get the appropriate VCC process environment
   var vcvars = vccVarsAll(vcvarsallArg, platformArg, sdkTypeArg, sdkVersionArg, verboseArg)
   if vcvars != nil: